@@ -13,9 +13,9 @@ ALL_DATA = {
     "Assize": {90: {"potency": {"6.55": 400}}, 100: {"potency": {"7.0": 400}}},
     "Dia (dot)": {
         90: {"potency": {"6.55": 65}},
-        100: {"potency": {"7.0": 70, "7.05": 75}},
+        100: {"potency": {"7.0": 70, "7.05": 75, "7.2": 80}},
     },
-    "Dia": {90: {"potency": {"6.55": 65}}, 100: {"potency": {"7.0": 70, "7.05": 75}}},
+    "Dia": {90: {"potency": {"6.55": 65}}, 100: {"potency": {"7.0": 70, "7.05": 75, "7.2": 80}}},
     "Afflatus Misery": {
         90: {"potency": {"6.55": 1240}},
         100: {"potency": {"7.0": 1320, "7.1": 1360}},
