@@ -2,10 +2,6 @@ import math
 
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
 from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
-from ama_xiv_combat_sim.simulator.game_data.convenience_timings import (
-    get_auto_timing,
-    get_instant_timing_spec,
-)
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
@@ -102,7 +98,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=840,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(
                 (raptor_fury_follow_up,)
@@ -203,7 +198,6 @@ class MnkSkills(GenericJobClass):
                 application_delay=self._skill_data.get_skill_data(
                     name, "primary_application_delay"
                 ),
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(
                 (
@@ -267,7 +261,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=1290,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=dragon_follow_up,
         )
@@ -394,7 +387,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=1110,
-                gcd_base_recast_time=2000,
             ),
         )
 
@@ -422,7 +414,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=800,
-                gcd_base_recast_time=2000,
             ),
         )
 
@@ -486,7 +477,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=760,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_opo_opo_form_follow_up(),),
         )
@@ -502,7 +492,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=940,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_opo_opo_form_follow_up(),),
             has_aoe=True,
@@ -519,7 +508,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=970,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(
                 tuple()
@@ -552,7 +540,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=1070,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_formless_fist_follow_up(),),
             has_aoe=True,
@@ -570,7 +557,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=890,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_formless_fist_follow_up(),),
         )
@@ -693,7 +679,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=400,
-                gcd_base_recast_time=2000,
             ),
             has_aoe=True,
         )
@@ -709,7 +694,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=760,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_formless_fist_follow_up(),),
             has_aoe=True,
@@ -727,7 +711,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=400,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_formless_fist_follow_up(),),
             has_aoe=True,
@@ -779,7 +762,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=620,
-                gcd_base_recast_time=2000,
             ),
         )
 
@@ -803,7 +785,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=890,
-                gcd_base_recast_time=2000,
             ),
         )
 
@@ -847,7 +828,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=1020,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_opo_opo_form_follow_up(),),
         )
@@ -865,7 +845,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=1420,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_formless_fist_follow_up(),),
             has_aoe=True,
@@ -885,7 +864,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=1200,
-                gcd_base_recast_time=2000,
             ),
             has_aoe=True,
             aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
@@ -904,7 +882,6 @@ class MnkSkills(GenericJobClass):
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=1420,
-                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(self.__get_formless_fist_follow_up(),),
             has_aoe=True,
@@ -932,7 +909,7 @@ class MnkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
-            timing_spec=TimingSpec(base_cast_time=0, gcd_base_recast_time=2000),
+            timing_spec=TimingSpec(base_cast_time=0),
             follow_up_skills=(self.__get_formless_fist_follow_up(),),
         )
 
