@@ -261,11 +261,11 @@ class TestJobsMultiUnified705(TestClass):
             # living shadow. only 2 of these cleave.
             ("Abyssal Drain (pet)", 12298),
             ("Shadowbringer (pet)", 16690),
-            ("Shadowbringer (pet)", 16690),
+            ("Shadowbringer (pet)", 8338),
             ("Edge of Shadow (pet)", 12297),
             ("Bloodspiller (pet)", 12302),
             ("Disesteem (pet)", 18151),
-            ("Disesteem (pet)", 18151),
+            ("Disesteem (pet)", 9071),
         )
 
         test_passed2, err_msg2 = self.__job_class_tester.test_rotation_damage(
@@ -565,22 +565,22 @@ class TestJobsMultiUnified705(TestClass):
         expected = (
             ("Cascade", 10671),
             ("Double Standard Finish", 41240),
-            ("Double Standard Finish", 41240),
+            ("Double Standard Finish", 10309),
             ("Cascade", 11195),
             #
             ("Cascade", 10671),
             ("Double Standard Finish", 41240),
-            ("Double Standard Finish", 41240),
+            ("Double Standard Finish", 10309),
             ("Cascade", 11195),
             #
             ("Cascade", 10678),
             ("Quadruple Technical Finish", 63075),
-            ("Quadruple Technical Finish", 63075),
+            ("Quadruple Technical Finish", 15768),
             ("Cascade", 11220),
             #
             ("Cascade", 10670),
             ("Quadruple Technical Finish", 63118),
-            ("Quadruple Technical Finish", 63118),
+            ("Quadruple Technical Finish", 15768),
             ("Cascade", 11200),
         )
 
@@ -955,7 +955,7 @@ class TestJobsMultiUnified705(TestClass):
             ("Death Blossom", 3967),
             #
             ("Kunai's Bane", 23820),
-            ("Kunai's Bane", 23820),
+            ("Kunai's Bane", 0.5*23820),
             ("Spinning Edge", 13076),
             ("Spinning Edge", 13076),
             ("Spinning Edge", 11906),
